<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:wz="http://www.tall.ox.ac.uk/schema/wcker/0.2" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:param name="step-number" select="1"/>
    <xsl:param name="highlight" select=""/>
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="newline">
        <xsl:text>
</xsl:text>
    </xsl:variable>
    <xsl:template match="/">
        <html>
            <head>
                <style>
                    <!--
===================================================================
       EDIT THE CSS STATEMENTS HERE TO STYLE THE 
       HELP FILE INCLUDING THE STYLE OF HIGHLIGHTED SECTIONS
===================================================================
-->
                    <xsl:comment>
				body {
				  background-color: #ffffff;
				  font-family: sans-serif;
				  font-size: 0.8em;
				}
				div {padding: 0.1em;}
				.desc {padding-left: 0.7em;}
				h1, h2, h3, h4, h5 {margin-top: 0.1em; margin-bottom: 0.1em; padding-left: 0.2em;}
				h1 {margin-top: 0.5em; font-size: 1.3em;}
				h2 {margin-top: 0.4em; font-size: 1.2em;}
				h3 {margin-top: 0.3em; font-size: 1.1em;}
				h4, h5 {font-size: 1em; padding-left: 0.3em;}
				.highlight {
					background-color: #558;
					color: white;
					border: 1px solid black;
				}
				.highlight div {background-color: #eee; color: black; padding-left: 0.7em;}
			</xsl:comment>
                    <!--
===================================================================
       END OF CSS SECTION - DON'T EDIT THE REST OF THE FILE
===================================================================
-->
                </style>
            </head>
            <body>
                <xsl:apply-templates select="//wz:step[number($step-number)]"/>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="wz:step">
        <xsl:element name="a">
            <xsl:attribute name="name">
                <xsl:value-of select="'top'"/>
            </xsl:attribute>
        </xsl:element>
        <h1>
            <xsl:value-of select="@title"/>
            <xsl:text> </xsl:text>
        </h1>
        <xsl:value-of select="$newline"/>
        <xsl:apply-templates select="wz:guidance"/>
        <xsl:value-of select="$newline"/>
        <xsl:apply-templates select="wz:applyToHeirarchy"/>
        <xsl:apply-templates select="wz:applyToItem"/>
    </xsl:template>
    <xsl:template match="wz:applyToHeirarchy">
        <xsl:value-of select="$newline"/>
        <xsl:element name="a">
            <xsl:attribute name="name">
                <xsl:value-of select="'hierarchy'"/>
            </xsl:attribute>
        </xsl:element>
        <hr/>
        <h2>
            <xsl:value-of select="wz:prompt"/>
            <xsl:text> </xsl:text>
        </h2>
        <xsl:value-of select="$newline"/>
        <xsl:apply-templates select="wz:applyToItem"/>
        <xsl:value-of select="$newline"/>
    </xsl:template>
    <xsl:template match="wz:applyToItem">
        <xsl:element name="div">
            <xsl:if test="$highlight = @targetHook">
                <xsl:attribute name="class">
                    <xsl:text>highlight</xsl:text>
                </xsl:attribute>
            </xsl:if>
            <xsl:element name="a">
                <xsl:attribute name="name">
                    <xsl:value-of select="@targetHook"/>
                </xsl:attribute>
            </xsl:element>
            <h3>
                <xsl:value-of select="wz:prompt"/>
                <xsl:text> </xsl:text>
            </h3>
            <xsl:apply-templates select="wz:guidance"/>
            <xsl:value-of select="$newline"/>
            <xsl:apply-templates select="wz:questionGroup"/>
            <xsl:value-of select="$newline"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="wz:questionGroup">
        <xsl:variable name="ref" select="@ref"/>
        <xsl:choose>
            <xsl:when test="string-length(@ref)>0">
                <xsl:apply-templates select="/wz:wizard/wz:questions/wz:questionGroup[@id = $ref]"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates select="wz:question"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="wz:question">
        <xsl:variable name="ref" select="concat(../@id, '-', count(preceding-sibling::wz:question)+1)"/>
        <xsl:element name="a">
            <xsl:attribute name="name">
                <xsl:value-of select="$ref"/>
            </xsl:attribute>
        </xsl:element>
        <xsl:element name="div">
            <xsl:attribute name="id">
                <xsl:value-of select="$ref"/>
            </xsl:attribute>
            <xsl:if test="$highlight = $ref">
                <xsl:attribute name="class">
                    <xsl:text>highlight</xsl:text>
                </xsl:attribute>
            </xsl:if>
            <xsl:value-of select="$newline"/>
            <h4>
                <xsl:value-of select="wz:prompt"/>
                <xsl:text> </xsl:text>
            </h4>
            <xsl:apply-templates select="wz:guidance"/>
        </xsl:element>
        <xsl:value-of select="$newline"/>
    </xsl:template>
    <xsl:template match="wz:guidance">
        <xsl:value-of select="$newline"/>
        <div class="desc">
            <xsl:apply-templates select="xhtml:html/xhtml:div"/>
            <xsl:value-of select="wz:plainText"/>
        </div>
        <xsl:value-of select="$newline"/>
    </xsl:template>
    <xsl:template match="*">
        <xsl:element name="{name()}">
            <xsl:for-each select="@*">
                <xsl:attribute name="{name()}">
                    <xsl:value-of select="."/>
                </xsl:attribute>
            </xsl:for-each>
            <xsl:apply-templates select="*|text()"/>
        </xsl:element>
    </xsl:template>
</xsl:stylesheet>
